@@ -1,4 +1,4 @@
-/* Copyright (C) 2017 Gabor Karsay <gabor.karsay@gmx.at>
+/* Copyright (C) 2017, 2020 Gabor Karsay <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -14,6 +14,34 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+/**
+ * pt-waveviewer-ruler
+ * Internal widget that draws the ruler for PtWaveviewer.
+ *
+ * When it's added to PtWaveviewer, it gets the horizontal GtkAdjustment from
+ * its parent (listening for the hierarchy-changed signal).
+ *
+ * Use pt_waveviewer_ruler_set_ruler() to set it up. @n_samples is the number
+ * of lines in the waveform or the width of the fully plotted waveform.
+ * @px_per_sec is how many pixels are worth one second and @duration is the
+ * duration in ms of the audio stream.
+ *
+ * The height of the ruler is determined by the height of the system font plus
+ * 5px for marks and 6px for padding.
+ *
+ * Marks (primary and secondary) are computed based on font size and pixel per
+ * second ratio.
+ *
+ * It listens to changes of the parent's horizontal GtkAdjustment and redraws
+ * itself (scroll movements, size changes).
+ *
+ * The widget listens to the style-updated signal (e.g. changed font size, color)
+ * and the state-flags-changed signal to update its height/color.
+ *
+ * The widget has a GTK_STYLE_CLASS_MARK and a name "ruler".
+ */
+
+
 #include "config.h"
 #define GETTEXT_PACKAGE GETTEXT_LIB
 #include <glib/gi18n-lib.h>
@@ -25,7 +53,6 @@
 #define SECONDARY_MARK_HEIGHT 4
 
 struct _PtWaveviewerRulerPrivate {
-	gboolean  rtl;
 	gint64    n_samples;
 	gint      px_per_sec;
 	gint64    duration;	/* in milliseconds */
@@ -43,25 +70,6 @@ struct _PtWaveviewerRulerPrivate {
 G_DEFINE_TYPE_WITH_PRIVATE (PtWaveviewerRuler, pt_waveviewer_ruler, GTK_TYPE_DRAWING_AREA);
 
 
-static gint64
-flip_pixel (PtWaveviewerRuler *self,
-            gint64             pixel)
-{
-	/* In ltr layouts each pixel on the x-axis corresponds to a sample in the array.
-	   In rtl layouts this is flipped, e.g. the first pixel corresponds to
-	   the last sample in the array. */
-
-	gint   widget_width;
-
-	widget_width = gtk_widget_get_allocated_width (GTK_WIDGET (self));
-
-	/* Case: waveform is shorter than drawing area */
-	if (self->priv->n_samples < widget_width)
-		return (widget_width - pixel);
-	else
-		return (self->priv->n_samples - pixel);
-}
-
 static gint64
 time_to_pixel (PtWaveviewerRuler *self,
                gint64             ms)
@@ -72,9 +80,6 @@ time_to_pixel (PtWaveviewerRuler *self,
 	result = ms * self->priv->px_per_sec;
 	result = result / 1000;
 
-	if (self->priv->rtl)
-		result = flip_pixel (self, result);
-
 	return result;
 }
 
@@ -85,9 +90,6 @@ pixel_to_time (PtWaveviewerRuler *self,
 	/* Convert a position in the drawing area to time in milliseconds */
 	gint64 result;
 
-	if (self->priv->rtl)
-		pixel = flip_pixel (self, pixel);
-
 	result = pixel * 1000;
 	result = result / self->priv->px_per_sec;
 
@@ -106,18 +108,19 @@ pt_waveviewer_ruler_draw (GtkWidget *widget,
 	gchar          *text;
 	PangoLayout    *layout;
 	PangoRectangle  rect;
-	gint            x_offset;
+	gint            halfwidth;
 	gint64          tmp_time;
 	GtkStyleContext *context;
 	GdkRGBA         text_color;
-	gdouble         left, right;
+	gint            width;
+	gint            offset;
+
+	width = gtk_widget_get_allocated_width (widget);
+	offset = (gint) gtk_adjustment_get_value (self->priv->adj);
 
-	cairo_clip_extents (cr, &left, NULL, &right, NULL);
 	context = gtk_widget_get_style_context (GTK_WIDGET (self));
-	gtk_render_background (context, cr,
-                               left, 0,
-                               right, height);
-	
+	gtk_render_background (context, cr, 0, 0, width, height);
+
 	if (self->priv->n_samples == 0)
 		return FALSE;
 
@@ -127,30 +130,23 @@ pt_waveviewer_ruler_draw (GtkWidget *widget,
 	   Get time of leftmost pixel, convert it to rounded 10th second,
 	   add 10th seconds until we are at the end of the view */
 	if (self->priv->primary_modulo == 1) {
-		tmp_time = pixel_to_time (self, (int)left) / 100 * 100;
-		if (self->priv->rtl)
-			tmp_time += 100; /* round up */
-		i = time_to_pixel (self, tmp_time);
-		while (i <= (int)right) {
+		tmp_time = pixel_to_time (self, offset) / 100 * 100;
+		i = time_to_pixel (self, tmp_time) - offset;
+		while (i <= width) {
 			if (tmp_time < self->priv->duration)
 				gtk_render_line (context, cr, i, 0, i, SECONDARY_MARK_HEIGHT);
-			if (self->priv->rtl)
-				tmp_time -= 100;
-			else
-				tmp_time += 100;
-			i = time_to_pixel (self, tmp_time);
+			tmp_time += 100;
+			i = time_to_pixel (self, tmp_time) - offset;
 		}
 	}
 
 	/* Case: secondary ruler marks for full seconds.
 	   Use secondary_modulo. */
 	if (self->priv->primary_modulo > 1) {
-		for (i = (int)left; i <= (int)right; i += 1) {
-			sample = i;
-			if (self->priv->rtl)
-				sample = flip_pixel (self, sample);
+		for (i = 0; i <= width; i += 1) {
+			sample = i + offset;
 			if (sample > self->priv->n_samples)
-				continue;
+				break;
 			if (sample % (self->priv->px_per_sec * self->priv->secondary_modulo) == 0)
 				gtk_render_line (context, cr, i, 0, i, SECONDARY_MARK_HEIGHT);
 		}
@@ -162,14 +158,10 @@ pt_waveviewer_ruler_draw (GtkWidget *widget,
 				     gtk_style_context_get_state (context),
 				     &text_color);
 	gdk_cairo_set_source_rgba (cr, &text_color);
-	for (i = (int)left - self->priv->time_string_width; i <= (int)right + self->priv->time_string_width; i += 1) {
-		sample = i;
-		if (self->priv->rtl)
-			sample = flip_pixel (self, sample);
+	for (i = 0 - self->priv->time_string_width; i <= width + self->priv->time_string_width; i += 1) {
+		sample = i + offset;
 		if (sample < 0 || sample > self->priv->n_samples)
 			continue;
-		if (self->priv->px_per_sec * self->priv->primary_modulo == 0)
-			g_print ("oops\n");
 		if (sample % (self->priv->px_per_sec * self->priv->primary_modulo) == 0) {
 			gtk_render_line (context, cr, i, 0, i, PRIMARY_MARK_HEIGHT);
 			if (self->priv->time_format_long) {
@@ -187,10 +179,10 @@ pt_waveviewer_ruler_draw (GtkWidget *widget,
 
 			/* display timestring only if it is fully visible in drawing area */
 			pango_layout_get_pixel_extents (layout, &rect, NULL);
-			x_offset = (rect.x + rect.width) / 2;
-			if (i - x_offset > 0 && i + x_offset < gtk_widget_get_allocated_width (widget)) {
+			halfwidth = rect.width / 2;
+			if (i - halfwidth > 0 && i + halfwidth < width) {
 				cairo_move_to (cr,
-					       i - x_offset,	/* center at mark */
+					       i - halfwidth,	/* center at mark */
 					       height - rect.y - rect.height -3); /* +3 px above border */
 				pango_cairo_show_layout (cr, layout);
 			}
@@ -270,35 +262,7 @@ calculate_height (PtWaveviewerRuler *self)
 	cairo_destroy (cr);
 	cairo_surface_destroy (surface);
 
-	gtk_widget_set_size_request (GTK_WIDGET (self), self->priv->n_samples, ruler_height);
-}
-
-static void
-update_cached_style_values (PtWaveviewerRuler *self)
-{
-	/* Direction is cached */
-
-	GtkStyleContext *context;
-	GdkWindow       *window = NULL;
-
-	window = gtk_widget_get_parent_window (GTK_WIDGET (self));
-	if (!window)
-		return;
-
-	context = gtk_widget_get_style_context (GTK_WIDGET (self));
-
-	if (gtk_style_context_get_state (context) & GTK_STATE_FLAG_DIR_RTL)
-		self->priv->rtl = TRUE;
-	else
-		self->priv->rtl = FALSE;
-}
-
-static void
-pt_waveviewer_ruler_state_flags_changed (GtkWidget     *widget,
-                                         GtkStateFlags  flags)
-{
-	update_cached_style_values (PT_WAVEVIEWER_RULER (widget));
-	GTK_WIDGET_CLASS (pt_waveviewer_ruler_parent_class)->state_flags_changed (widget, flags);
+	gtk_widget_set_size_request (GTK_WIDGET (self), -1, ruler_height);
 }
 
 static void
@@ -309,30 +273,15 @@ pt_waveviewer_ruler_style_updated (GtkWidget *widget)
 	GTK_WIDGET_CLASS (pt_waveviewer_ruler_parent_class)->style_updated (widget);
 
 	calculate_height (self);
-	update_cached_style_values (self);
 	gtk_widget_queue_draw (widget);
 }
 
-static void
-pt_waveviewer_ruler_realize (GtkWidget *widget)
-{
-	GTK_WIDGET_CLASS (pt_waveviewer_ruler_parent_class)->realize (widget);
-	update_cached_style_values (PT_WAVEVIEWER_RULER (widget));
-}
-
 static void
 adj_value_changed (GtkAdjustment *adj,
                    gpointer       data)
 {
 	PtWaveviewerRuler *self = PT_WAVEVIEWER_RULER (data);
-	gint height, width, left;
-
-	height = gtk_widget_get_allocated_height (GTK_WIDGET (self));
-	width = (gint) gtk_adjustment_get_page_size (self->priv->adj);
-	left = (gint) gtk_adjustment_get_value (self->priv->adj);
-	gtk_widget_queue_draw_area (GTK_WIDGET (self),
-				    left, 0,
-				    width, height);
+	gtk_widget_queue_draw (GTK_WIDGET (self));
 }
 
 static void
@@ -346,7 +295,7 @@ pt_waveviewer_ruler_hierarchy_changed (GtkWidget *widget,
 
 	/* Get parent’s GtkAdjustment */
 	GtkWidget *parent = NULL;
-	parent = gtk_widget_get_ancestor (widget, PT_TYPE_WAVEVIEWER);
+	parent = gtk_widget_get_ancestor (widget, GTK_TYPE_SCROLLED_WINDOW);
 	if (parent) {
 		self->priv->adj = gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (parent));
 		g_signal_connect (self->priv->adj, "value-changed", G_CALLBACK (adj_value_changed), self);
@@ -364,7 +313,6 @@ pt_waveviewer_ruler_set_ruler (PtWaveviewerRuler *self,
 	self->priv->duration = duration;
 
 	calculate_height (self);
-	update_cached_style_values (self);
 	gtk_widget_queue_draw (GTK_WIDGET (self));
 }
 
@@ -392,8 +340,6 @@ pt_waveviewer_ruler_class_init (PtWaveviewerRulerClass *klass)
 
 	widget_class->draw                = pt_waveviewer_ruler_draw;
 	widget_class->hierarchy_changed   = pt_waveviewer_ruler_hierarchy_changed;
-	widget_class->realize             = pt_waveviewer_ruler_realize;
-	widget_class->state_flags_changed = pt_waveviewer_ruler_state_flags_changed;
 	widget_class->style_updated       = pt_waveviewer_ruler_style_updated;
 }
 
