@@ -4,12 +4,12 @@
  * modify it under the terms of the GNU General Public License as published
  * by the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -18,6 +18,7 @@
 #include <glib.h>
 #include <gst/gst.h> /* error domain */
 #include <pt-player.h>
+#include "mock-plugin.h"
 
 
 /* Fixture ------------------------------------------------------------------ */
@@ -32,15 +33,12 @@ static void
 pt_player_fixture_set_up (PtPlayerFixture *fixture,
 			  gconstpointer    user_data)
 {
-	GError *error = NULL;
 	fixture->testplayer = NULL;
 	gchar    *path;
 	GFile    *file;
 	gboolean  success;
 
 	fixture->testplayer = pt_player_new ();
-	pt_player_setup_player (fixture->testplayer, &error);
-	g_assert_no_error (error);
 
 	path = g_test_build_filename (G_TEST_DIST, "data", "tick-10sec.ogg", NULL);
 	/* In make distcheck the path is something like /_build/../data/test1.ogg".
@@ -74,7 +72,6 @@ player_new (void)
 {
 	/* create new PtPlayer and test initial properties */
 
-	GError *error = NULL;
 	PtPlayer *testplayer;
 
 	/* Construction properties */
@@ -88,8 +85,6 @@ player_new (void)
 	gint pause, back, forward;
 
 	testplayer = pt_player_new ();
-	pt_player_setup_player (testplayer, &error);
-	g_assert_no_error (error);
 	g_assert_true (PT_IS_PLAYER (testplayer));
 	g_object_set (testplayer,
 		      "pause", 0,
@@ -123,6 +118,10 @@ player_new (void)
 	g_assert_cmpstr (t_delimiter, ==, "#");
 	g_assert_cmpstr (t_separator, ==, ".");
 
+	g_assert_cmpint (pt_player_get_pause (testplayer), ==, pause);
+	g_assert_cmpint (pt_player_get_back (testplayer), ==, back);
+	g_assert_cmpint (pt_player_get_forward (testplayer), ==, forward);
+
 	g_free (t_delimiter);
 	g_free (t_separator);
 	g_object_unref (testplayer);
@@ -150,15 +149,12 @@ player_open_fail (void)
 {
 	PtPlayer    *player;
 	ErrorCBData  data;
-	GError      *error = NULL;
 	gboolean     success;
 	gchar       *path;
 	GFile       *file;
 	gchar       *uri;
 
 	player = pt_player_new ();
-	pt_player_setup_player (player, &error);
-	g_assert_no_error (error);
 
 	/* Fails to open "foo" */
 	data.loop = g_main_loop_new (g_main_context_default (), FALSE);
@@ -206,7 +202,7 @@ player_open_ogg (PtPlayerFixture *fixture,
 	/* open test file, get and check uri and filename */
 
 	gchar *getchar;
-	
+
 	getchar = pt_player_get_uri (fixture->testplayer);
 	g_assert_cmpstr (getchar, ==, fixture->testuri);
 	g_free (getchar);
@@ -216,6 +212,26 @@ player_open_ogg (PtPlayerFixture *fixture,
 	g_free (getchar);
 }
 
+static void
+player_selections (PtPlayerFixture *fixture,
+                   gconstpointer    user_data)
+{
+	/* set, get and clear a selection */
+
+	gboolean selection;
+
+	selection = pt_player_selection_active (fixture->testplayer);
+	g_assert_false (selection);
+
+	pt_player_set_selection (fixture->testplayer, 1000, 2000);
+	selection = pt_player_selection_active (fixture->testplayer);
+	g_assert_true (selection);
+
+	pt_player_clear_selection (fixture->testplayer);
+	selection = pt_player_selection_active (fixture->testplayer);
+	g_assert_false (selection);
+}
+
 static void
 player_timestamps (PtPlayerFixture *fixture,
 		   gconstpointer    user_data)
@@ -348,7 +364,7 @@ player_timestamps (PtPlayerFixture *fixture,
 	g_assert_cmpint (60200, ==, pt_player_get_timestamp_position (fixture->testplayer, "00:01:00-2", FALSE));
 
 	pt_player_jump_to_position (fixture->testplayer, 1000);
-	
+
 	timestamp = pt_player_get_timestamp (fixture->testplayer);
 	g_assert_nonnull (timestamp);
 
@@ -374,10 +390,9 @@ player_volume_speed (PtPlayerFixture *fixture,
 {
 	/* set speed and volume properties */
 
-	GError *error = NULL;
 	PtPlayer *bind_player;
 	gdouble speed, volume;
-	
+
 	pt_player_set_volume (fixture->testplayer, 0.7);
 	pt_player_set_speed (fixture->testplayer, 0.7);
 
@@ -394,15 +409,15 @@ player_volume_speed (PtPlayerFixture *fixture,
 	pt_player_set_mute (fixture->testplayer, TRUE);
 	g_object_get (fixture->testplayer, "volume", &volume, NULL);
 	g_assert_cmpfloat_with_epsilon (volume, 0.7, 0.00001);
+	g_assert_true (pt_player_get_mute (fixture->testplayer));
 
 	pt_player_set_mute (fixture->testplayer, FALSE);
 	g_object_get (fixture->testplayer, "volume", &volume, NULL);
 	g_assert_cmpfloat_with_epsilon (volume, 0.7, 0.00001);
+	g_assert_false (pt_player_get_mute (fixture->testplayer));
 
 	/* check bind property */
 	bind_player = pt_player_new ();
-	pt_player_setup_player (bind_player, &error);
-	g_assert_no_error (error);
 
 	g_object_bind_property (fixture->testplayer, "volume",
 				bind_player, "volume",
@@ -421,7 +436,7 @@ player_volume_speed (PtPlayerFixture *fixture,
 	g_assert_cmpfloat (volume, ==, 0.5);
 	g_assert_cmpfloat (speed, ==, 0.5);
 
-	g_object_unref (bind_player);	
+	g_object_unref (bind_player);
 }
 
 static void
@@ -498,6 +513,47 @@ player_timestrings (PtPlayerFixture *fixture,
 	g_free (timestring);
 }
 
+static void
+player_config_loadable (void)
+{
+	PtPlayer *testplayer;
+	PtConfig *good, *bad;
+	GFile    *testfile;
+	gchar    *testpath;
+	gboolean  success;
+
+	/* Create player */
+	testplayer = pt_player_new ();
+	g_assert_true (PT_IS_PLAYER (testplayer));
+	mock_plugin_register ();
+
+	/* Create config with existing plugin */
+	testpath = g_test_build_filename (G_TEST_DIST, "data", "config-mock-plugin.asr", NULL);
+	testfile = g_file_new_for_path (testpath);
+	good = pt_config_new (testfile);
+	g_assert_true (pt_config_is_valid (good));
+	g_object_unref (testfile);
+	g_free (testpath);
+
+	/* Create config with missing plugin*/
+	testpath = g_test_build_filename (G_TEST_DIST, "data", "config-test.asr", NULL);
+	testfile = g_file_new_for_path (testpath);
+	bad = pt_config_new (testfile);
+	g_assert_true (pt_config_is_valid (bad));
+	g_object_unref (testfile);
+	g_free (testpath);
+
+	success = pt_player_config_is_loadable (testplayer, good);
+	g_assert_true (success);
+
+	success = pt_player_config_is_loadable (testplayer, bad);
+	g_assert_false (success);
+
+	g_object_unref (good);
+	g_object_unref (bad);
+	g_object_unref (testplayer);
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -508,6 +564,9 @@ main (int argc, char *argv[])
 	g_test_add ("/player/open-ogg", PtPlayerFixture, NULL,
 	            pt_player_fixture_set_up, player_open_ogg,
 	            pt_player_fixture_tear_down);
+	g_test_add ("/player/selections", PtPlayerFixture, NULL,
+	            pt_player_fixture_set_up, player_selections,
+	            pt_player_fixture_tear_down);
 	g_test_add ("/player/timestamps", PtPlayerFixture, NULL,
 	            pt_player_fixture_set_up, player_timestamps,
 	            pt_player_fixture_tear_down);
@@ -517,6 +576,7 @@ main (int argc, char *argv[])
 	g_test_add ("/player/timestrings", PtPlayerFixture, NULL,
 	            pt_player_fixture_set_up, player_timestrings,
 	            pt_player_fixture_tear_down);
+	g_test_add_func ("/player/config-loadable", player_config_loadable);
 
 	return g_test_run ();
 }
