@@ -4,12 +4,12 @@
  * modify it under the terms of the GNU General Public License as published
  * by the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -106,8 +106,6 @@ waveviewer_loaded (void)
 	SyncData   data;
 
 	player = pt_player_new ();
-	pt_player_setup_player (player, &error);
-	g_assert_no_error (error);
 
 	testpath = g_test_build_filename (G_TEST_DIST, "data", "tick-10sec.ogg", NULL);
 	testfile = g_file_new_for_path (testpath);
