@@ -5,7 +5,7 @@ APP_ID=$1
 
 MSYSTEM=MSYS2 . /etc/profile
 
-while read lang
+while read -r lang
 do
 	if [[ ${lang:0:1} != "#" && ${lang:0:1} != " " ]]
 	then
@@ -14,4 +14,4 @@ do
 		(cd "$dest" && yelp-build html -o . .) || exit 1
 		rm "$dest"/*.page
 	fi
-done < "${MESON_SOURCE_ROOT}"/help/LINGUAS
\ No newline at end of file
+done < "${MESON_SOURCE_ROOT}"/help/LINGUAS
