@@ -4,12 +4,12 @@
  * modify it under the terms of the GNU General Public License as published
  * by the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -17,7 +17,7 @@
 
 #include "config.h"
 #include <gtk/gtk.h>
-#include <glib/gi18n.h>	
+#include <glib/gi18n.h>
 #include <locale.h>		/* setlocale */
 #include "pt-app.h"
 
@@ -25,10 +25,10 @@
 int main (int argc, char *argv[])
 {
 	setlocale (LC_ALL, "");
-	bindtextdomain (PACKAGE, LOCALEDIR);
-	bind_textdomain_codeset (PACKAGE, "UTF-8");
-	textdomain (PACKAGE);
-	
+	bindtextdomain (PACKAGE_NAME, LOCALEDIR);
+	bind_textdomain_codeset (PACKAGE_NAME, "UTF-8");
+	textdomain (PACKAGE_NAME);
+
 	PtApp *app;
 	gint   app_status;
 
