@@ -4,12 +4,12 @@
  * modify it under the terms of the GNU General Public License as published
  * by the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -17,7 +17,7 @@
 
 #include "config.h"
 #include <gtk/gtk.h>
-#include <glib/gi18n.h>	
+#include <glib/gi18n.h>
 #ifdef G_OS_UNIX
   #include "pt-dbus-service.h"
   #include "pt-mediakeys.h"
@@ -34,9 +34,6 @@
 
 struct _PtAppPrivate
 {
-	gboolean       asr;
-	gboolean       atspi;
-	PtAsrSettings *asr_settings;
 #ifdef G_OS_UNIX
 	PtMediakeys   *mediakeys;
 	PtDbusService *dbus_service;
@@ -62,27 +59,29 @@ static GOptionEntry options[] =
 	  N_("Show the application’s version"),
 	  NULL
 	},
-#ifdef HAVE_ASR
-	{ "with-asr",
-	  'a',
-	  G_OPTION_FLAG_NONE,
-	  G_OPTION_ARG_NONE,
-	  NULL,
-	  N_("Enable automatic speech recognition"),
-	  NULL
-	},
-	{ "textpad",
-	  't',
-	  G_OPTION_FLAG_NONE,
-	  G_OPTION_ARG_NONE,
-	  NULL,
-	  N_("Use internal textpad for automatic speech recognition"),
-	  NULL
-	},
-#endif
 	{ NULL }
 };
 
+static void
+open_dialog_response_cb (GtkDialog *dialog,
+			 gint       response_id,
+			 gpointer   user_data)
+{
+	PtWindow *win = PT_WINDOW (user_data);
+	gchar    *uri = NULL;
+
+	if (response_id == GTK_RESPONSE_ACCEPT) {
+		uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (dialog));
+	}
+
+	if (uri) {
+		pt_window_open_file (PT_WINDOW (win), uri);
+		g_free (uri);
+	}
+
+	g_object_unref (dialog);
+}
+
 static void
 open_cb (GSimpleAction *action,
          GVariant      *parameter,
@@ -95,7 +94,6 @@ open_cb (GSimpleAction *action,
 	GFile	      *current, *dir;
 	GtkFileFilter *filter_audio;
 	GtkFileFilter *filter_all;
-	gchar         *uri = NULL;
 
 	win = gtk_application_get_active_window (app);
 	dialog = gtk_file_chooser_native_new (
@@ -134,17 +132,10 @@ open_cb (GSimpleAction *action,
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter_all);
 	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter_audio);
 
-	if (gtk_native_dialog_run (GTK_NATIVE_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
-		uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (dialog));
-	}
+	g_signal_connect (dialog, "response", G_CALLBACK (open_dialog_response_cb), win);
+	gtk_native_dialog_show (GTK_NATIVE_DIALOG (dialog));
 
 	g_object_unref (dir);
-	g_object_unref (dialog);
-
-	if (uri) {
-		pt_window_open_file (PT_WINDOW (win), uri);
-		g_free (uri);
-	}
 }
 
 static void
@@ -220,7 +211,7 @@ about_cb (GSimpleAction *action,
 			gtk_application_get_active_window (app),
 			"program_name", _("Parlatype"),
 			"version", PACKAGE_VERSION,
-			"copyright", "© Gabor Karsay 2016–2020",
+			"copyright", "© Gabor Karsay 2016–2021",
 			"comments", _("A basic transcription utility"),
 			"logo-icon-name", APP_ID,
 			"authors", authors,
@@ -247,27 +238,6 @@ const GActionEntry app_actions[] = {
 	{ "quit", quit_cb, NULL, NULL, NULL }
 };
 
-PtAsrSettings*
-pt_app_get_asr_settings (PtApp *app)
-{
-	g_assert (PT_IS_APP (app));
-	return app->priv->asr_settings;
-}
-
-gboolean
-pt_app_get_atspi (PtApp *app)
-{
-	g_assert (PT_IS_APP (app));
-	return app->priv->atspi;
-}
-
-gboolean
-pt_app_get_asr (PtApp *app)
-{
-	g_assert (PT_IS_APP (app));
-	return app->priv->asr;
-}
-
 static void
 pt_app_startup (GApplication *app)
 {
@@ -286,6 +256,9 @@ pt_app_startup (GApplication *app)
 	const gchar *help_accels[2] = { "F1", NULL };
 	const gchar *zoom_in_accels[3] = { "<Primary>plus", "<Primary>KP_Add", NULL };
 	const gchar *zoom_out_accels[3] = { "<Primary>minus", "<Primary>KP_Subtract", NULL };
+	const char *jump_back_accels[2] = {"<Primary>Left", NULL};
+	const char *jump_forward_accels[2] = {"<Primary>Right", NULL};
+	const char *play_accels[2] = {"<Primary>space", NULL};
 
 	gtk_application_set_accels_for_action (GTK_APPLICATION (app),
 			"app.quit", quit_accels);
@@ -311,6 +284,15 @@ pt_app_startup (GApplication *app)
 	gtk_application_set_accels_for_action (GTK_APPLICATION (app),
 			"win.zoom-out", zoom_out_accels);
 
+	gtk_application_set_accels_for_action (GTK_APPLICATION (app),
+			"win.jump-back", jump_back_accels);
+
+	gtk_application_set_accels_for_action (GTK_APPLICATION (app),
+			"win.jump-forward", jump_forward_accels);
+
+	gtk_application_set_accels_for_action (GTK_APPLICATION (app),
+			"win.play", play_accels);
+
 	/* Load custom css */
 	GtkCssProvider *provider;
 	provider = gtk_css_provider_new ();
@@ -390,54 +372,14 @@ static gint
 pt_app_handle_local_options (GApplication *application,
                              GVariantDict *options)
 {
-	PtApp *app = PT_APP (application);
-
 	if (g_variant_dict_contains (options, "version")) {
-		g_print ("%s %s\n", PACKAGE, VERSION);
+		g_print ("%s %s\n", PACKAGE_NAME, PACKAGE_VERSION);
 		return 0;
 	}
 
-	if (g_variant_dict_contains (options, "with-asr")) {
-		app->priv->asr = TRUE;
-	}
-
-	if (g_variant_dict_contains (options, "textpad")) {
-		app->priv->atspi = FALSE;
-	}
-
 	return -1;
 }
 
-static gchar*
-get_asr_settings_filename (void)
-{
-	const gchar *userdir;
-	gchar	    *configdir;
-	GFile	    *create_dir;
-	gchar       *filename;
-
-	userdir = g_get_user_data_dir ();
-	configdir = g_build_path ("/", userdir, PACKAGE, NULL);
-	create_dir = g_file_new_for_path (configdir);
-	g_file_make_directory (create_dir, NULL, NULL);
-	filename = g_build_filename (configdir, "asr.ini", NULL);
-
-	g_free (configdir);
-	g_object_unref (create_dir);
-
-	return filename;
-}
-
-static gboolean
-is_flatpak (void)
-{
-	/* Flatpak sandboxes have a file ".flatpak-info" in their filesystem root.
-	   It's a keyfile, an example how to read is get_flatpak_information() in
-	   https://gitlab.gnome.org/GNOME/recipes/blob/master/src/gr-about-dialog.c */
-
-	return (g_file_test ("/.flatpak-info", G_FILE_TEST_EXISTS));
-}
-
 static void
 pt_app_init (PtApp *app)
 {
@@ -453,26 +395,13 @@ pt_app_init (PtApp *app)
 	app->priv->win32pipe = NULL;
 #endif
 	g_application_add_main_option_entries (G_APPLICATION (app), options);
-
-	/* In Flatpak's sandbox ATSPI doesn't work */
-	if (is_flatpak ())
-		app->priv->atspi = FALSE;
-	else
-		app->priv->atspi = TRUE;
-
-	app->priv->asr = FALSE;
-	gchar *asr_settings_filename;
-	asr_settings_filename = get_asr_settings_filename ();
-	app->priv->asr_settings = pt_asr_settings_new (asr_settings_filename);
-	g_free (asr_settings_filename);
 }
 
 static void
-pt_app_finalize (GObject *object)
+pt_app_dispose (GObject *object)
 {
 	PtApp *app = PT_APP (object);
 
-	g_clear_object (&app->priv->asr_settings);
 #ifdef G_OS_UNIX
 	g_clear_object (&app->priv->mediakeys);
 	g_clear_object (&app->priv->dbus_service);
@@ -492,7 +421,7 @@ pt_app_class_init (PtAppClass *klass)
 	GApplicationClass    *gapp_class    = G_APPLICATION_CLASS (klass);
 	GObjectClass         *gobject_class = G_OBJECT_CLASS (klass);
 
-	gobject_class->finalize          = pt_app_finalize;
+	gobject_class->dispose           = pt_app_dispose;
 	gapp_class->open                 = pt_app_open;
 	gapp_class->activate             = pt_app_activate;
 	gapp_class->startup              = pt_app_startup;
